==> org.eclipse.e4.ui.workbench.source_1.5.1.v20170815-1446.jar: org/eclipse/e4/ui/internal/workbench/Policy.java <==
/*******************************************************************************
 * Copyright (c) 2013, 2015 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.e4.ui.internal.workbench;

/**
 * A common facility for parsing the
 * <code>org.eclipse.e4.ui.workbench/.options</code> file.
 *
 */
public class Policy {
	public static final String DEBUG_FLAG = "/debug"; //$NON-NLS-1$
	public static final String DEBUG_CMDS_FLAG = "/trace/commands"; //$NON-NLS-1$
	public static final String DEBUG_MENUS_FLAG = "/trace/menus"; //$NON-NLS-1$
	public static final String DEBUG_CONTEXTS_FLAG = "/trace/eclipse.context"; //$NON-NLS-1$
	public static final String DEBUG_CONTEXTS_VERBOSE_FLAG = "/trace/eclipse.context.verbose"; //$NON-NLS-1$
	public static final String DEBUG_WORKBENCH_FLAG = "/trace/workbench"; //$NON-NLS-1$
	public static final String DEBUG_RENDERER_FLAG = "/trace/renderer"; //$NON-NLS-1$

	/***/
	public static boolean DEBUG;
	/***/
	public static boolean DEBUG_CMDS;
	/***/
	public static boolean DEBUG_MENUS;
	/***/
	public static boolean DEBUG_CONTEXTS;
	/***/
	public static boolean DEBUG_CONTEXTS_VERBOSE;
	/***/
	public static boolean DEBUG_WORKBENCH;
	/***/
	public static boolean DEBUG_RENDERER;
}

==> org.eclipse.e4.ui.workbench.source_1.6.0.v20180516-2019.jar: org/eclipse/e4/ui/internal/workbench/Policy.java <==
/*******************************************************************************
 * Copyright (c) 2013, 2015 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.e4.ui.internal.workbench;

/**
 * A common facility for parsing the
 * <code>org.eclipse.e4.ui.workbench/.options</code> file.
 *
 */
public class Policy {
	public static final String DEBUG_FLAG = "/debug"; //$NON-NLS-1$
	public static final String TRACE_FLAG = "/trace"; //$NON-NLS-1$
	public static final String DEBUG_FOCUS_FLAG = "/trace/focus"; //$NON-NLS-1$
	public static final String DEBUG_CMDS_FLAG = "/trace/commands"; //$NON-NLS-1$
	public static final String DEBUG_MENUS_FLAG = "/trace/menus"; //$NON-NLS-1$
	public static final String DEBUG_CONTEXTS_FLAG = "/trace/eclipse.context"; //$NON-NLS-1$
	public static final String DEBUG_CONTEXTS_VERBOSE_FLAG = "/trace/eclipse.context.verbose"; //$NON-NLS-1$
	public static final String DEBUG_WORKBENCH_FLAG = "/trace/workbench"; //$NON-NLS-1$
	public static final String DEBUG_RENDERER_FLAG = "/trace/renderer"; //$NON-NLS-1$

	/***/
	public static boolean DEBUG;
	/***/
	public static boolean TRACE;
	/***/
	public static boolean DEBUG_CMDS;
	/***/
	public static boolean DEBUG_FOCUS;
	/***/
	public static boolean DEBUG_MENUS;
	/***/
	public static boolean DEBUG_CONTEXTS;
	/***/
	public static boolean DEBUG_CONTEXTS_VERBOSE;
	/***/
	public static boolean DEBUG_WORKBENCH;
	/***/
	public static boolean DEBUG_RENDERER;
}
